@@ -9,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
  
@@ -87,9 +86,10 @@ enum FILESYSTEM
 	FS_USED            = 24,
 	FS_UNUSED          = 25,
 
-	FS_LUKS            = 26,
-	FS_LINUX_SWRAID    = 27,
-	FS_LINUX_SWSUSPEND = 28
+	FS_BITLOCKER       = 26,
+	FS_LUKS            = 27,
+	FS_LINUX_SWRAID    = 28,
+	FS_LINUX_SWSUSPEND = 29
 } ;
 
 enum SIZE_UNIT
