@@ -9,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/DialogFeatures.h" 
@@ -27,7 +26,8 @@ DialogFeatures::DialogFeatures()
 {
 	set_title( _("File System Support") ) ;
 	set_has_separator( false ) ;
-	set_resizable( false ) ;
+	//Set minimum dialog height so it fits on an 800x600 screen
+	set_size_request( -1, 500 ) ;
 
 	//initialize icons
 	icon_yes = render_icon( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR );
@@ -59,84 +59,75 @@ DialogFeatures::DialogFeatures()
 	treeview_filesystems .get_selection() ->set_mode( Gtk::SELECTION_NONE );
 	treeview_filesystems .set_rules_hint( true ) ;
 
-	{
-		Gtk::HBox* hbox(manage(new Gtk::HBox()));
+	//scrollable file system list
+	filesystems_scrolled .set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC ) ;
+	filesystems_scrolled .add( treeview_filesystems ) ;
 
-		hbox->set_border_width(6);
-		hbox->pack_start(treeview_filesystems);
-		get_vbox()->pack_start(*hbox);
+	Gtk::HBox *filesystems_hbox( manage( new Gtk::HBox() ) ) ;
+	filesystems_hbox ->set_border_width( 6 ) ;
+	filesystems_hbox ->pack_start( filesystems_scrolled ) ;
+	this ->get_vbox() ->pack_start( *filesystems_hbox ) ;
 
-		//file system support legend
-		Gtk::HBox* hbox2(manage(new Gtk::HBox(false, 6)));
-		hbox2->set_border_width(6);
+	//file system support legend
+	Gtk::HBox *legend_hbox( manage( new Gtk::HBox( false, 6 ) ) ) ;
+	legend_hbox ->set_border_width( 6 ) ;
 
-		hbox = manage(new Gtk::HBox());
-		{
-			Glib::ustring str_temp(_("This chart shows the actions supported on file systems."));
-			str_temp += "\n" ;
-			str_temp += _("Not all actions are available on all file systems, in part due to the nature of file systems and limitations in the required software.");
-			hbox->pack_start(*Utils::mk_label(str_temp, true, true),
-					Gtk::PACK_SHRINK);
-			hbox2->pack_start(*hbox);
+	Gtk::HBox *legend_narrative_hbox( manage( new Gtk::HBox() ) ) ;
+	Glib::ustring str_temp( _("This chart shows the actions supported on file systems.") ) ;
+	str_temp += "\n" ;
+	str_temp += _("Not all actions are available on all file systems, in part due to the nature of file systems and limitations in the required software.") ;
+	legend_narrative_hbox ->pack_start( *Utils::mk_label( str_temp, true, true ), Gtk::PACK_SHRINK ) ;
+	legend_hbox ->pack_start( *legend_narrative_hbox, Gtk::PACK_EXPAND_WIDGET, 6 ) ;
 
-			{
-				//icon legend
-				Gtk::VBox* vbox(manage(new Gtk::VBox()));
+	//icon legend
+	Gtk::VBox *icon_legend_vbox( manage( new Gtk::VBox() ) ) ;
 
-				hbox = manage(new Gtk::HBox());
+	Gtk::HBox *available_both_hbox( manage( new Gtk::HBox() ) ) ;
+	Gtk::Image *image_yes( manage( new Gtk::Image( icon_yes ) ) ) ;
+	available_both_hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK ) ;
+	image_yes = manage( new Gtk::Image( icon_yes ) ) ;
+	available_both_hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK ) ;
+	available_both_hbox ->pack_start( *Utils::mk_label(
+			/* TO TRANSLATORS:  Available offline and online
+			* means that this action is valid for this file system when
+			* it is both unmounted and mounted.
+			*/
+			_("Available offline and online")), Gtk::PACK_EXPAND_WIDGET ) ;
+	icon_legend_vbox ->pack_start( *available_both_hbox ) ;
 
-				{
-					Gtk::Image *image_yes( manage( new Gtk::Image( icon_yes ) ) );
-					hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK );
-					image_yes = manage( new Gtk::Image( icon_yes ) );
-					hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK );
-					hbox->pack_start(*Utils::mk_label(
-							/* TO TRANSLATORS:  Available offline and online
-							* means that this action is valid for this file system when
-							* it is both unmounted and mounted.
-							*/
-							_("Available offline and online")), Gtk::PACK_EXPAND_WIDGET );
-					vbox ->pack_start(*hbox);
+	Gtk::HBox *available_offline_hbox = manage(new Gtk::HBox() ) ;
+	image_yes = manage( new Gtk::Image( icon_yes ) ) ;
+	available_offline_hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK ) ;
+	Gtk::Image *image_blank( manage( new Gtk::Image( icon_blank ) ) ) ;
+	available_offline_hbox ->pack_start( *image_blank, Gtk::PACK_SHRINK ) ;
+	available_offline_hbox ->pack_start( *Utils::mk_label(
+			/* TO TRANSLATORS:  Available offline only
+			* means that this action is valid for this file system only
+			* when it is unmounted.
+			*/
+			_("Available offline only")), Gtk::PACK_EXPAND_WIDGET ) ;
+	icon_legend_vbox ->pack_start( *available_offline_hbox ) ;
 
-					hbox = manage(new Gtk::HBox() );
-					image_yes = manage( new Gtk::Image( icon_yes ) );
-					hbox ->pack_start( *image_yes, Gtk::PACK_SHRINK );
-					Gtk::Image *image_blank( manage( new Gtk::Image( icon_blank ) ) );
-					hbox ->pack_start( *image_blank, Gtk::PACK_SHRINK );
-					hbox ->pack_start( *Utils::mk_label(
-							/* TO TRANSLATORS:  Available offline only
-							* means that this action is valid for this file system only
-							* when it is unmounted.
-							*/
-							_("Available offline only")), Gtk::PACK_EXPAND_WIDGET );
-					vbox ->pack_start( *hbox );
+	Gtk::HBox *not_available_hbox = manage( new Gtk::HBox() ) ;
+	Gtk::Image *image_no( manage( new Gtk::Image( icon_no ) ) ) ;
+	not_available_hbox ->pack_start( *image_no, Gtk::PACK_SHRINK ) ;
+	image_blank = manage( new Gtk::Image( icon_blank ) ) ;
+	not_available_hbox ->pack_start( *image_blank, Gtk::PACK_SHRINK ) ;
+	not_available_hbox->pack_start(*Utils::mk_label(
+			/* TO TRANSLATORS:  Not Available
+			* means that this action is not valid for this file system.
+			*/
+			_("Not Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
+	icon_legend_vbox ->pack_start( *not_available_hbox ) ;
+	legend_hbox ->pack_start( *icon_legend_vbox ) ;
 
-					hbox = manage(new Gtk::HBox());
-					Gtk::Image *image_no( manage( new Gtk::Image( icon_no ) ) );
-					hbox ->pack_start( *image_no, Gtk::PACK_SHRINK );
-					image_blank = manage( new Gtk::Image( icon_blank ) );
-					hbox ->pack_start( *image_blank, Gtk::PACK_SHRINK );
-				}
-
-				hbox->pack_start(*Utils::mk_label(
-						/* TO TRANSLATORS:  Not Available
-						* means that this action is not valid for this file system.
-						*/
-						_("Not Available") ), Gtk::PACK_EXPAND_WIDGET);
-				vbox->pack_start(*hbox);
-				hbox2->pack_start(*vbox);
-			}
-
-			str_temp = "<b>";
-			str_temp += _("Legend");
-			str_temp += "</b>";
-			expander_legend.set_label(str_temp);
-			expander_legend.set_use_markup(true);
-		}
-
-		get_vbox()->pack_start(expander_legend, Gtk::PACK_SHRINK);
-		expander_legend.add(*hbox2);
-	}
+	str_temp = "<b>" ;
+	str_temp += _("Legend") ;
+	str_temp += "</b>" ;
+	legend_frame .set_label_widget( *Utils::mk_label( str_temp ) ) ;
+	legend_frame .set_shadow_type( Gtk::SHADOW_NONE ) ;
+	legend_frame .add( *legend_hbox ) ;
+	this ->get_vbox() ->pack_start( legend_frame, Gtk::PACK_SHRINK ) ;
 
 	/*TO TRANSLATORS: This is a button that will search for the software tools installed and then refresh the screen with the file system actions supported. */
 	add_button( _("Rescan For Supported Actions"), Gtk::RESPONSE_OK );
@@ -154,6 +145,7 @@ void DialogFeatures::load_filesystems( const std::vector<FS> & FILESYSTEMS )
 		//Skip non-file systems or file systems only recognised but not otherwise supported
 		if (    FILESYSTEMS[ t ] .filesystem == FS_UNKNOWN
 		     || FILESYSTEMS[ t ] .filesystem == FS_CLEARED
+		     || FILESYSTEMS[ t ] .filesystem == FS_BITLOCKER
 		     || FILESYSTEMS[ t ] .filesystem == FS_LUKS
 		     || FILESYSTEMS[ t ] .filesystem == FS_LINUX_SWRAID
 		     || FILESYSTEMS[ t ] .filesystem == FS_LINUX_SWSUSPEND
