@@ -9,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "../include/Dialog_Partition_New.h"
@@ -53,6 +52,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	{
 		if (   f ->filesystem == FS_UNKNOWN
 		    || f ->filesystem == FS_CLEARED
+		    || f ->filesystem == FS_BITLOCKER
 		    || f ->filesystem == FS_LUKS
 		    || f ->filesystem == FS_LINUX_SWRAID
 		    || f ->filesystem == FS_LINUX_SWSUSPEND
