@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -9,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/Win_GParted.h"
@@ -419,6 +418,7 @@ Gtk::Menu * Win_GParted::create_format_menu()
 		//Skip non-file systems or file systems only recognised but not otherwise supported
 		if (    fss[ t ] .filesystem == FS_UNKNOWN
 		     || fss[ t ] .filesystem == FS_CLEARED
+		     || fss[ t ] .filesystem == FS_BITLOCKER
 		     || fss[ t ] .filesystem == FS_LUKS
 		     || fss[ t ] .filesystem == FS_LINUX_SWRAID
 		     || fss[ t ] .filesystem == FS_LINUX_SWSUSPEND
@@ -1474,7 +1474,7 @@ void Win_GParted::menu_help_about()
 	dialog .set_logo_icon_name( "gparted" ) ;
 	dialog .set_version( VERSION ) ;
 	dialog .set_comments( _( "GNOME Partition Editor" ) ) ;
-	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2013 Curtis Gedak" ) ;
+	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2014 Curtis Gedak" ) ;
 
 	//authors
 	//Names listed in alphabetical order by LAST name.
@@ -2333,7 +2333,7 @@ void Win_GParted::activate_disklabel()
 	}
 
 	//Display dialog for creating a new partition table.
-	Dialog_Disklabel dialog( devices[ current_device ] .get_path(), gparted_core .get_disklabeltypes() ) ;
+	Dialog_Disklabel dialog( devices[ current_device ] ) ;
 	dialog .set_transient_for( *this );
 
 	if ( dialog .run() == Gtk::RESPONSE_APPLY )
