@@ -9,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
  
@@ -166,7 +165,7 @@ bool reiserfs::resize( const Partition & partition_new, OperationDetail & operat
 	Glib::ustring size = "" ;
 	if ( ! fill_partition )
 	{
-		size = " -s " + Utils::num_to_str( Utils::round( Utils::sector_to_unit(
+		size = " -s " + Utils::num_to_str( floor( Utils::sector_to_unit(
 		                   partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) ) ;
 	}
 	Glib::ustring cmd = "sh -c 'echo y | resize_reiserfs" + size + " " + partition_new .get_path() + "'" ;
